Documentation
¶
Index ¶
- func Certificate_IsConstruct(x interface{}) *bool
- func Certificate_IsTerraformElement(x interface{}) *bool
- func Certificate_IsTerraformResource(x interface{}) *bool
- func Certificate_TfResourceType() *string
- func NewCertificateDnsChallengeList_Override(c CertificateDnsChallengeList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewCertificateDnsChallengeOutputReference_Override(c CertificateDnsChallengeOutputReference, ...)
- func NewCertificateHttpChallengeOutputReference_Override(c CertificateHttpChallengeOutputReference, ...)
- func NewCertificateHttpMemcachedChallengeOutputReference_Override(c CertificateHttpMemcachedChallengeOutputReference, ...)
- func NewCertificateHttpWebrootChallengeOutputReference_Override(c CertificateHttpWebrootChallengeOutputReference, ...)
- func NewCertificateTlsChallengeOutputReference_Override(c CertificateTlsChallengeOutputReference, ...)
- func NewCertificate_Override(c Certificate, scope constructs.Construct, id *string, ...)
- type Certificate
- type CertificateConfig
- type CertificateDnsChallenge
- type CertificateDnsChallengeList
- type CertificateDnsChallengeOutputReference
- type CertificateHttpChallenge
- type CertificateHttpChallengeOutputReference
- type CertificateHttpMemcachedChallenge
- type CertificateHttpMemcachedChallengeOutputReference
- type CertificateHttpWebrootChallenge
- type CertificateHttpWebrootChallengeOutputReference
- type CertificateTlsChallenge
- type CertificateTlsChallengeOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Certificate_IsConstruct ¶
func Certificate_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Certificate_IsTerraformElement ¶
func Certificate_IsTerraformElement(x interface{}) *bool
Experimental.
func Certificate_IsTerraformResource ¶
func Certificate_IsTerraformResource(x interface{}) *bool
Experimental.
func Certificate_TfResourceType ¶
func Certificate_TfResourceType() *string
func NewCertificateDnsChallengeList_Override ¶
func NewCertificateDnsChallengeList_Override(c CertificateDnsChallengeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCertificateDnsChallengeOutputReference_Override ¶
func NewCertificateDnsChallengeOutputReference_Override(c CertificateDnsChallengeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCertificateHttpChallengeOutputReference_Override ¶
func NewCertificateHttpChallengeOutputReference_Override(c CertificateHttpChallengeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCertificateHttpMemcachedChallengeOutputReference_Override ¶
func NewCertificateHttpMemcachedChallengeOutputReference_Override(c CertificateHttpMemcachedChallengeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCertificateHttpWebrootChallengeOutputReference_Override ¶
func NewCertificateHttpWebrootChallengeOutputReference_Override(c CertificateHttpWebrootChallengeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCertificateTlsChallengeOutputReference_Override ¶
func NewCertificateTlsChallengeOutputReference_Override(c CertificateTlsChallengeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCertificate_Override ¶
func NewCertificate_Override(c Certificate, scope constructs.Construct, id *string, config *CertificateConfig)
Create a new {@link https://www.terraform.io/docs/providers/acme/r/certificate acme_certificate} Resource.
Types ¶
type Certificate ¶
type Certificate interface {
cdktf.TerraformResource
AccountKeyPem() *string
SetAccountKeyPem(val *string)
AccountKeyPemInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateDomain() *string
CertificateNotAfter() *string
CertificateP12() *string
CertificateP12Password() *string
SetCertificateP12Password(val *string)
CertificateP12PasswordInput() *string
CertificatePem() *string
CertificateRequestPem() *string
SetCertificateRequestPem(val *string)
CertificateRequestPemInput() *string
CertificateUrl() *string
CommonName() *string
SetCommonName(val *string)
CommonNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisableCompletePropagation() interface{}
SetDisableCompletePropagation(val interface{})
DisableCompletePropagationInput() interface{}
DnsChallenge() CertificateDnsChallengeList
DnsChallengeInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HttpChallenge() CertificateHttpChallengeOutputReference
HttpChallengeInput() *CertificateHttpChallenge
HttpMemcachedChallenge() CertificateHttpMemcachedChallengeOutputReference
HttpMemcachedChallengeInput() *CertificateHttpMemcachedChallenge
HttpWebrootChallenge() CertificateHttpWebrootChallengeOutputReference
HttpWebrootChallengeInput() *CertificateHttpWebrootChallenge
Id() *string
SetId(val *string)
IdInput() *string
IssuerPem() *string
KeyType() *string
SetKeyType(val *string)
KeyTypeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MinDaysRemaining() *float64
SetMinDaysRemaining(val *float64)
MinDaysRemainingInput() *float64
MustStaple() interface{}
SetMustStaple(val interface{})
MustStapleInput() interface{}
// The tree node.
Node() constructs.Node
PreCheckDelay() *float64
SetPreCheckDelay(val *float64)
PreCheckDelayInput() *float64
PreferredChain() *string
SetPreferredChain(val *string)
PreferredChainInput() *string
PrivateKeyPem() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RecursiveNameservers() *[]*string
SetRecursiveNameservers(val *[]*string)
RecursiveNameserversInput() *[]*string
RevokeCertificateOnDestroy() interface{}
SetRevokeCertificateOnDestroy(val interface{})
RevokeCertificateOnDestroyInput() interface{}
SubjectAlternativeNames() *[]*string
SetSubjectAlternativeNames(val *[]*string)
SubjectAlternativeNamesInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TlsChallenge() CertificateTlsChallengeOutputReference
TlsChallengeInput() *CertificateTlsChallenge
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDnsChallenge(value interface{})
PutHttpChallenge(value *CertificateHttpChallenge)
PutHttpMemcachedChallenge(value *CertificateHttpMemcachedChallenge)
PutHttpWebrootChallenge(value *CertificateHttpWebrootChallenge)
PutTlsChallenge(value *CertificateTlsChallenge)
ResetCertificateP12Password()
ResetCertificateRequestPem()
ResetCommonName()
ResetDisableCompletePropagation()
ResetDnsChallenge()
ResetHttpChallenge()
ResetHttpMemcachedChallenge()
ResetHttpWebrootChallenge()
ResetId()
ResetKeyType()
ResetMinDaysRemaining()
ResetMustStaple()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPreCheckDelay()
ResetPreferredChain()
ResetRecursiveNameservers()
ResetRevokeCertificateOnDestroy()
ResetSubjectAlternativeNames()
ResetTlsChallenge()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/acme/r/certificate acme_certificate}.
func NewCertificate ¶
func NewCertificate(scope constructs.Construct, id *string, config *CertificateConfig) Certificate
Create a new {@link https://www.terraform.io/docs/providers/acme/r/certificate acme_certificate} Resource.
type CertificateConfig ¶
type CertificateConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#account_key_pem Certificate#account_key_pem}.
AccountKeyPem *string `field:"required" json:"accountKeyPem" yaml:"accountKeyPem"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#certificate_p12_password Certificate#certificate_p12_password}.
CertificateP12Password *string `field:"optional" json:"certificateP12Password" yaml:"certificateP12Password"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#certificate_request_pem Certificate#certificate_request_pem}.
CertificateRequestPem *string `field:"optional" json:"certificateRequestPem" yaml:"certificateRequestPem"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#common_name Certificate#common_name}.
CommonName *string `field:"optional" json:"commonName" yaml:"commonName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#disable_complete_propagation Certificate#disable_complete_propagation}.
DisableCompletePropagation interface{} `field:"optional" json:"disableCompletePropagation" yaml:"disableCompletePropagation"`
// dns_challenge block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#dns_challenge Certificate#dns_challenge}
DnsChallenge interface{} `field:"optional" json:"dnsChallenge" yaml:"dnsChallenge"`
// http_challenge block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#http_challenge Certificate#http_challenge}
HttpChallenge *CertificateHttpChallenge `field:"optional" json:"httpChallenge" yaml:"httpChallenge"`
// http_memcached_challenge block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#http_memcached_challenge Certificate#http_memcached_challenge}
HttpMemcachedChallenge *CertificateHttpMemcachedChallenge `field:"optional" json:"httpMemcachedChallenge" yaml:"httpMemcachedChallenge"`
// http_webroot_challenge block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#http_webroot_challenge Certificate#http_webroot_challenge}
HttpWebrootChallenge *CertificateHttpWebrootChallenge `field:"optional" json:"httpWebrootChallenge" yaml:"httpWebrootChallenge"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#id Certificate#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#key_type Certificate#key_type}.
KeyType *string `field:"optional" json:"keyType" yaml:"keyType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#min_days_remaining Certificate#min_days_remaining}.
MinDaysRemaining *float64 `field:"optional" json:"minDaysRemaining" yaml:"minDaysRemaining"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#must_staple Certificate#must_staple}.
MustStaple interface{} `field:"optional" json:"mustStaple" yaml:"mustStaple"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#pre_check_delay Certificate#pre_check_delay}.
PreCheckDelay *float64 `field:"optional" json:"preCheckDelay" yaml:"preCheckDelay"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#preferred_chain Certificate#preferred_chain}.
PreferredChain *string `field:"optional" json:"preferredChain" yaml:"preferredChain"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#recursive_nameservers Certificate#recursive_nameservers}.
RecursiveNameservers *[]*string `field:"optional" json:"recursiveNameservers" yaml:"recursiveNameservers"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#revoke_certificate_on_destroy Certificate#revoke_certificate_on_destroy}.
RevokeCertificateOnDestroy interface{} `field:"optional" json:"revokeCertificateOnDestroy" yaml:"revokeCertificateOnDestroy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#subject_alternative_names Certificate#subject_alternative_names}.
SubjectAlternativeNames *[]*string `field:"optional" json:"subjectAlternativeNames" yaml:"subjectAlternativeNames"`
// tls_challenge block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#tls_challenge Certificate#tls_challenge}
TlsChallenge *CertificateTlsChallenge `field:"optional" json:"tlsChallenge" yaml:"tlsChallenge"`
}
type CertificateDnsChallenge ¶
type CertificateDnsChallenge struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#provider Certificate#provider}.
Provider *string `field:"required" json:"provider" yaml:"provider"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#config Certificate#config}.
Config *map[string]*string `field:"optional" json:"config" yaml:"config"`
}
type CertificateDnsChallengeList ¶
type CertificateDnsChallengeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CertificateDnsChallengeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCertificateDnsChallengeList ¶
func NewCertificateDnsChallengeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CertificateDnsChallengeList
type CertificateDnsChallengeOutputReference ¶
type CertificateDnsChallengeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Config() *map[string]*string
SetConfig(val *map[string]*string)
ConfigInput() *map[string]*string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Provider() *string
SetProvider(val *string)
ProviderInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCertificateDnsChallengeOutputReference ¶
func NewCertificateDnsChallengeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CertificateDnsChallengeOutputReference
type CertificateHttpChallenge ¶
type CertificateHttpChallenge struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#port Certificate#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#proxy_header Certificate#proxy_header}.
ProxyHeader *string `field:"optional" json:"proxyHeader" yaml:"proxyHeader"`
}
type CertificateHttpChallengeOutputReference ¶
type CertificateHttpChallengeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CertificateHttpChallenge
SetInternalValue(val *CertificateHttpChallenge)
Port() *float64
SetPort(val *float64)
PortInput() *float64
ProxyHeader() *string
SetProxyHeader(val *string)
ProxyHeaderInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPort()
ResetProxyHeader()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCertificateHttpChallengeOutputReference ¶
func NewCertificateHttpChallengeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CertificateHttpChallengeOutputReference
type CertificateHttpMemcachedChallenge ¶
type CertificateHttpMemcachedChallenge struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#hosts Certificate#hosts}.
Hosts *[]*string `field:"required" json:"hosts" yaml:"hosts"`
}
type CertificateHttpMemcachedChallengeOutputReference ¶
type CertificateHttpMemcachedChallengeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hosts() *[]*string
SetHosts(val *[]*string)
HostsInput() *[]*string
InternalValue() *CertificateHttpMemcachedChallenge
SetInternalValue(val *CertificateHttpMemcachedChallenge)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCertificateHttpMemcachedChallengeOutputReference ¶
func NewCertificateHttpMemcachedChallengeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CertificateHttpMemcachedChallengeOutputReference
type CertificateHttpWebrootChallenge ¶
type CertificateHttpWebrootChallenge struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#directory Certificate#directory}.
Directory *string `field:"required" json:"directory" yaml:"directory"`
}
type CertificateHttpWebrootChallengeOutputReference ¶
type CertificateHttpWebrootChallengeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Directory() *string
SetDirectory(val *string)
DirectoryInput() *string
// Experimental.
Fqn() *string
InternalValue() *CertificateHttpWebrootChallenge
SetInternalValue(val *CertificateHttpWebrootChallenge)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCertificateHttpWebrootChallengeOutputReference ¶
func NewCertificateHttpWebrootChallengeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CertificateHttpWebrootChallengeOutputReference
type CertificateTlsChallenge ¶
type CertificateTlsChallenge struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/acme/r/certificate#port Certificate#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
}
type CertificateTlsChallengeOutputReference ¶
type CertificateTlsChallengeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CertificateTlsChallenge
SetInternalValue(val *CertificateTlsChallenge)
Port() *float64
SetPort(val *float64)
PortInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPort()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCertificateTlsChallengeOutputReference ¶
func NewCertificateTlsChallengeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CertificateTlsChallengeOutputReference
Source Files
¶
- Certificate.go
- CertificateConfig.go
- CertificateDnsChallenge.go
- CertificateDnsChallengeList.go
- CertificateDnsChallengeList__checks.go
- CertificateDnsChallengeOutputReference.go
- CertificateDnsChallengeOutputReference__checks.go
- CertificateHttpChallenge.go
- CertificateHttpChallengeOutputReference.go
- CertificateHttpChallengeOutputReference__checks.go
- CertificateHttpMemcachedChallenge.go
- CertificateHttpMemcachedChallengeOutputReference.go
- CertificateHttpMemcachedChallengeOutputReference__checks.go
- CertificateHttpWebrootChallenge.go
- CertificateHttpWebrootChallengeOutputReference.go
- CertificateHttpWebrootChallengeOutputReference__checks.go
- CertificateTlsChallenge.go
- CertificateTlsChallengeOutputReference.go
- CertificateTlsChallengeOutputReference__checks.go
- Certificate__checks.go
- main.go